@@ -1,7 +1,7 @@
 import os
 import unittest
 from httpretty import HTTPretty, httprettified
-from fanart.music import Artist
+from fanart.music import *
 from fanart.tests import LOCALDIR
 os.environ['FANART_APIKEY'] = 'e3c7f0d0beeaf45b3a0dd3b9dd8a3338'
 
@@ -18,3 +18,4 @@ class ArtistItemTestCase(unittest.TestCase):
         )
         a7f = Artist.get(id='24e1b53c-3085-4581-8472-0b0088d2508c')
         self.assertEqual(a7f.mbid, '24e1b53c-3085-4581-8472-0b0088d2508c')
+        self.assertEqual(a7f, eval(repr(a7f)))
